$(document).ready(function() {
  // Replaces createApplet(), see its function header
  createAppletAtPath(Drupal.settings.jzebra.library_path);
  // Once the applet has loaded, execute the given function
  monitorLoadingThenCall('initialize()');

  $('#printnow input:submit').click(function() {
    printContent();
    return false;
  });
});

/**
 * Initialize the page by displaying the jZebra library version and populating
 * the printer list.
 */
function initialize() {
  $('#jzebra_version').html($j.getVersion());
  $('#jzebra_message_loading').hide();
  $('#jzebra_message_version').show();
  $('#jzebra_printers').show();

  $('#jzebra_printer_list').html('');
  // It looks like jZebra can't populate its internal printer list without
  // searching for one, but this returns an error if a printer whose name starts
  // with the first parameter below isn't found. Oh well, let's trick it and
  // supply an empty name.
  getPrinterThenCall('', 'populatePrinters()');
}

/**
 * Callback for when initialize() finishes searching for printers. Displays the
 * printers in a bullet list, allowing the user to select one.
 */
function populatePrinters() {
  $.each(getPrinters(), function(i,v) {
    var li = $('<li><a href="#">' + v + '</a></li>');
    $(li).click(function() {
      $('#jzebra_printers ul li').css('font-weight', 'normal');
      $(this).css('font-weight', 'bold');
      // This sets the an internal state in the applet that keeps track of the
      // 'current' printer. The current printer can later be retrieved with
      // $j.getPrinterName().
      getPrinterThenCall(v, 'showPrintButton()');
      return false;
    });
    $('#jzebra_printers ul').append(li); 
  });
}

/**
 * Callback for when the user selects a printer to use. Shows the print button.
 */
function showPrintButton() {
   $("#printnow").show();
}

/**
 * Callback for the submit button, actually sents the file to the printer.
 */
function printContent() {
   $j.appendFile(Drupal.settings.jzebra.file_path);
   $j.print();
   alert("Data sent to printer. You can close the jZebra page.");
}

/**
 * Similar to jZebra's native createApplet() but allows us to specify the applet
 * path. Upon completion, the global variable $j holds the reference to the
 * applet.
 *
 * @param path
 *   The absolute location (URL) where jzebra.jar can be found.
 */
function createAppletAtPath(path) {
   var jZebra = document.createElement('applet');
   jZebra.setAttribute('name', 'jzebra');
   jZebra.setAttribute('code', 'jzebra.PrintApplet.class');
   jZebra.setAttribute('alt', 'Could not load loading jZebra applet');
   jZebra.setAttribute('archive', path + '/jzebra.jar');
   jZebra.setAttribute('width', '0');
   jZebra.setAttribute('height', '0');
   $('body').append(jZebra);
}